@@ -111,7 +111,7 @@ final global = UnmodifiableListView([
     r"$hue, $saturation": (arguments) {
       // hsl(123, var(--foo)) is valid CSS because --foo might be `10%, 20%` and
       // functions are parsed after variable substitution.
-      if (arguments[0].isVar || arguments[1].isVar) {
+      if (arguments[0].isSpecialVariable || arguments[1].isSpecialVariable) {
         return _functionString('hsl', arguments);
       } else {
         throw SassScriptException(r"Missing argument $lightness.");
@@ -130,7 +130,7 @@ final global = UnmodifiableListView([
         _hsl("hsla", arguments),
     r"$hue, $saturation, $lightness": (arguments) => _hsl("hsla", arguments),
     r"$hue, $saturation": (arguments) {
-      if (arguments[0].isVar || arguments[1].isVar) {
+      if (arguments[0].isSpecialVariable || arguments[1].isSpecialVariable) {
         return _functionString('hsla', arguments);
       } else {
         throw SassScriptException(r"Missing argument $lightness.");
@@ -170,7 +170,7 @@ final global = UnmodifiableListView([
     warnForDeprecation(
       "adjust-hue() is deprecated. Suggestion:\n"
       "\n"
-      "color.adjust(\$color, \$hue: $suggestedValue)\n"
+      "color.adjust(\$color, \$hue: ${suggestedValue.toCssString()})\n"
       "\n"
       "More info: https://sass-lang.com/d/color-functions",
       Deprecation.colorFunctions,
@@ -1390,7 +1390,8 @@ Value _rgbTwoArg(String name, List<Value> arguments) {
   // and functions are parsed after variable substitution.
   var first = arguments[0];
   var second = arguments[1];
-  if (first.isVar || (first is! SassColor && second.isVar)) {
+  if (first.isSpecialVariable ||
+      (first is! SassColor && second.isSpecialVariable)) {
     return _functionString(name, arguments);
   }
 
@@ -1668,7 +1669,7 @@ Value _parseChannels(
   ColorSpace? space,
   String? name,
 }) {
-  if (input.isVar) return _functionString(functionName, [input]);
+  if (input.isSpecialVariable) return _functionString(functionName, [input]);
 
   var parsedSlash = _parseSlashChannels(input, name: name);
   if (parsedSlash == null) return _functionString(functionName, [input]);
@@ -1684,14 +1685,15 @@ Value _parseChannels(
         when text.toLowerCase() == "from":
       return _functionString(functionName, [input]);
 
-    case _ when components.isVar:
+    case _ when components.isSpecialVariable:
       channels = [components];
 
     case [var first, ...var rest] && var componentList:
       if (space == null) {
         spaceName = first.assertString(name)..assertUnquoted(name);
-        space =
-            spaceName.isVar ? null : ColorSpace.fromName(spaceName.text, name);
+        space = spaceName.isSpecialVariable
+            ? null
+            : ColorSpace.fromName(spaceName.text, name);
         channels = rest;
 
         if (space
@@ -2019,7 +2021,7 @@ String _suggestScaleAndAdjust(
     var factorNumber = SassNumber(factor * 100, '%');
     suggestion += "s:\n"
         "\n"
-        "color.scale(\$color, \$$channelName: $factorNumber)\n";
+        "color.scale(\$color, \$$channelName: ${factorNumber.toCssString()})\n";
   } else {
     suggestion += ":\n\n";
   }
@@ -2028,7 +2030,8 @@ String _suggestScaleAndAdjust(
     adjustment,
     channel == ColorChannel.alpha ? null : '%',
   );
-  return suggestion + "color.adjust(\$color, \$$channelName: $difference)";
+  return suggestion +
+      "color.adjust(\$color, \$$channelName: ${difference.toCssString()})";
 }
 
 /// Throws an error indicating that a missing channel named [name] can't be
@@ -2037,7 +2040,7 @@ Never _missingChannelError(SassColor color, String channel) =>
     throw SassScriptException(
       "Because the CSS working group is still deciding on the best behavior, "
       "Sass doesn't currently support modifying missing channels (color: "
-      "$color).",
+      "${color.toCssString()}).",
       channel,
     );
 
